[FFmpeg-devel] [PATCH 6/8] doc/texi2pod: Handle @samp and @url inside verbatim blocks

Timothy Gu timothygu99 at gmail.com
Thu Jan 23 05:04:04 CET 2014


From: "Joseph S. Myers" <jsm at polyomino.org.uk>

Taken from part of GCC r133794 with minor tweaks to match 1f9855db.

Signed-off-by: Timothy Gu <timothygu99 at gmail.com>
---
 doc/texi2pod.pl | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/doc/texi2pod.pl b/doc/texi2pod.pl
index ef7402f..3e10782 100755
--- a/doc/texi2pod.pl
+++ b/doc/texi2pod.pl
@@ -235,9 +235,11 @@ INF: while(<$inf>) {
     s/\@\}/}/g;
     s/\@\@/&at;/g;
 
     # Inside a verbatim block, handle @var specially.
     if ($shift ne "") {
         s/\@var\{([^\}]*)\}/<$1>/g;
+        s/\@samp\{([^\}]*)\}/<$1>/g;
+        s/\@url\{([^\},]*),?[^\}]*\}/<$1>/g;
     }
 
     # POD doesn't interpret E<> inside a verbatim block.
@@ -235,9 +235,11 @@ INF: while(<$inf>) {
     s/\@\@/&at;/g;
 
-    # Inside a verbatim block, handle @var specially.
+    # Inside a verbatim block, handle @var, @samp and @url specially.
     if ($shift ne "") {
         s/\@var\{([^\}]*)\}/<$1>/g;
-- 
1.8.3.2



More information about the ffmpeg-devel mailing list